@@ -3,9 +3,15 @@
 
 def test_build_command(mip_cli):
     # GIVEN just a config
-    mip_config = 'tests/fixtures/global_config.yaml'
-    case_id = 'angrybird'
+    mip_config = "tests/fixtures/global_config.yaml"
+    case_id = "angrybird"
     # WHEN building the MIP command
     mip_command = mip_cli.build_command(case=case_id, config=mip_config)
     # THEN it should use the correct options
-    assert mip_command == [mip_cli.script, mip_cli.pipeline, case_id, '--config_file', mip_config]
+    assert mip_command == [
+        mip_cli.script,
+        mip_cli.pipeline,
+        case_id,
+        "--config_file",
+        mip_config,
+    ]
