@@ -41,7 +41,9 @@ def base(context, config, database, root, log_level):
 
 
 @base.command("log")
-@click.option("-s", "--sampleinfo", type=click.Path(exists=True), help="sample info file")
+@click.option(
+    "-s", "--sampleinfo", type=click.Path(exists=True), help="sample info file"
+)
 @click.option("-a", "--sacct", type=click.Path(exists=True), help="sacct job info file")
 @click.option("-q", "--quiet", is_flag=True, help="supress outputs")
 @click.argument("config", type=click.File())
@@ -55,10 +57,16 @@ def log_cmd(context, sampleinfo, sacct, quiet, config):
     try:
         new_run = log_analysis(config, sampleinfo=sampleinfo, sacct=sacct)
     except MissingFileError as error:
-        click.echo(click.style(f"Skipping, missing Sacct file: {error.message}", fg="red"))
+        click.echo(
+            click.style(f"Skipping, missing Sacct file: {error.message}", fg="red")
+        )
         return
     except KeyError as error:
-        print(click.style(f"unexpected output, missing key: {error.args[0]} in {config}", fg="red"))
+        print(
+            click.style(
+                f"unexpected output, missing key: {error.args[0]} in {config}", fg="red"
+            )
+        )
         return
     if new_run is None:
         if not quiet:
@@ -71,7 +79,9 @@ def log_cmd(context, sampleinfo, sacct, quiet, config):
 @base.command()
 @click.option("-c", "--mip-config", type=click.Path(exists=True), help="MIP config")
 @click.option("-e", "--email", help="email for logging user")
-@click.option("-p", "--priority", type=click.Choice(["low", "normal", "high"]), default="normal")
+@click.option(
+    "-p", "--priority", type=click.Choice(["low", "normal", "high"]), default="normal"
+)
 @click.option("-d", "--dryrun", is_flag=True, help="only generate SBATCH scripts")
 @click.option("--command", is_flag=True, help="only show the MIP command")
 @click.option(
@@ -84,7 +94,9 @@ def log_cmd(context, sampleinfo, sacct, quiet, config):
 @click.pass_context
 def start(context, mip_config, email, priority, dryrun, command, start_with, case):
     """Start a new analysis."""
-    mip_cli = MipCli(context.obj["script"], context.obj["pipeline"], context.obj["conda_env"])
+    mip_cli = MipCli(
+        context.obj["script"], context.obj["pipeline"], context.obj["conda_env"]
+    )
     mip_config = mip_config or context.obj["mip_config"]
     email = email or environ_email()
     kwargs = dict(
@@ -124,7 +136,9 @@ def init(context, reset, force):
         context.abort()
 
     context.obj["store"].setup()
-    message = f"Success! New tables: {', '.join(context.obj['store'].engine.table_names())}"
+    message = (
+        f"Success! New tables: {', '.join(context.obj['store'].engine.table_names())}"
+    )
     click.echo(click.style(message, fg="green"))
 
 
