@@ -16,7 +16,9 @@ def get(context, comment):
                 f"[{run_obj.type.upper()}/{run_obj.status.upper()}]"
             )
             if run_obj.status == "running":
-                message = click.style(f"{message} - {run_obj.progress * 100}/100", fg="blue")
+                message = click.style(
+                    f"{message} - {run_obj.progress * 100}/100", fg="blue"
+                )
             elif run_obj.status == "completed":
                 message = click.style(f"{message} - {run_obj.completed_at}", fg="green")
             elif run_obj.status == "failed":
