@@ -4,6 +4,6 @@ import os
 
 def environ_email():
     """Guess email from sudo user environment variable."""
-    username = os.environ.get('SUDO_USER')
+    username = os.environ.get("SUDO_USER")
     if username:
         return f"{username}@scilifelab.se"
